import React, { useContext } from 'react'
import { AppContext } from 'components/Contexts/AppContextProvider'
import { ScreenType } from 'enum/screen.enum'
import SplashContainer from '../SplashContainer/SplashContainer'

interface ContentProps {
  children?: React.ReactNode
  height?: number
  background?: string
}

const Content: React.FC<ContentProps> = ({
  children,
  height = 0,
  background = 'inherit',
}: ContentProps) => {
  const { isContextLoaded, screenType } = useContext(AppContext)
  const cozyBarHeight = 48
  const cozyNavHeight = 56
  return (
    <>
      {!isContextLoaded ? (
        <SplashContainer />
      ) : (
        <div
          className="content-view"
          style={{
            marginTop: height,
            paddingBottom: 0,
            minHeight:
              screenType !== ScreenType.DESKTOP
                ? `calc(100vh - ${height}px - ${cozyBarHeight}px - ${cozyNavHeight}px)`
                : `unset`,
            background: background,
          }}
        >
          {children}
        </div>
      )}
    </>
  )
}

export default Content
