import React, { useState, useEffect, useRef, useContext } from 'react'
import { ScreenType } from 'enum/screen.enum'
import { history } from 'components/ContainerComponents/ViewContainer/ViewContainer'
import { translate } from 'cozy-ui/react/I18n'
import StyledIconButton from 'components/CommonKit/IconButton/StyledIconButton'
import BackArrowIcon from 'assets/icons/ico/back-arrow.svg'
import { AppContext } from 'components/Contexts/AppContextProvider'

interface CozyBarProps {
  titleKey?: string
  displayBackArrow?: boolean
  t: Function
}

const CozyBar = ({
  titleKey = 'COMMON.APP_TITLE',
  displayBackArrow = false,
  t,
}: CozyBarProps) => {
  const { BarLeft, BarCenter } = cozy.bar
  const { screenType } = useContext(AppContext)

  const handleClickBack = () => {
    history.goBack()
  }

  const cozyBarCustom = (screen?: ScreenType) => {
    if (screen === ScreenType.MOBILE) {
      return (
        <React.Fragment>
          {displayBackArrow && (
            <BarLeft>
              <StyledIconButton
                className="cv-button"
                icon={BackArrowIcon}
                onClick={() => handleClickBack()}
              />
            </BarLeft>
          )}
          <BarCenter>
            <div className="cozy-bar">
              <span className="app-title">{t(titleKey)}</span>
            </div>
          </BarCenter>
        </React.Fragment>
      )
    }
    return null
  }

  return cozyBarCustom(screenType)
}

export default translate()(CozyBar)
